@@ -48,6 +48,7 @@ __all__ = (
     "S3InputFileTypeType",
     "SAPODataConnectorOperatorType",
     "SalesforceConnectorOperatorType",
+    "SalesforceDataTransferApiType",
     "ScheduleFrequencyTypeType",
     "ServiceNowConnectorOperatorType",
     "SingularConnectorOperatorType",
@@ -176,6 +177,7 @@ OperatorPropertiesKeysType = Literal[
     "DATA_TYPE",
     "DESTINATION_DATA_TYPE",
     "EXCLUDE_SOURCE_FIELDS_LIST",
+    "INCLUDE_NEW_FIELDS",
     "LOWER_BOUND",
     "MASK_LENGTH",
     "MASK_VALUE",
@@ -309,6 +311,7 @@ SalesforceConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
+SalesforceDataTransferApiType = Literal["AUTOMATIC", "BULKV2", "REST_SYNC"]
 ScheduleFrequencyTypeType = Literal["BYMINUTE", "DAILY", "HOURLY", "MONTHLY", "ONCE", "WEEKLY"]
 ServiceNowConnectorOperatorType = Literal[
     "ADDITION",
@@ -461,6 +464,7 @@ ServiceName = Literal[
     "autoscaling-plans",
     "backup",
     "backup-gateway",
+    "backupstorage",
     "batch",
     "billingconductor",
     "braket",
@@ -501,7 +505,10 @@ ServiceName = Literal[
     "config",
     "connect",
     "connect-contact-lens",
+    "connectcampaigns",
+    "connectcases",
     "connectparticipant",
+    "controltower",
     "cur",
     "customer-profiles",
     "databrew",
@@ -579,6 +586,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -605,12 +613,14 @@ ServiceName = Literal[
     "lexv2-models",
     "lexv2-runtime",
     "license-manager",
+    "license-manager-user-subscriptions",
     "lightsail",
     "location",
     "logs",
     "lookoutequipment",
     "lookoutmetrics",
     "lookoutvision",
+    "m2",
     "machinelearning",
     "macie",
     "macie2",
@@ -632,6 +642,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
@@ -657,6 +668,7 @@ ServiceName = Literal[
     "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
+    "privatenetworks",
     "proton",
     "qldb",
     "qldb-session",
@@ -667,11 +679,13 @@ ServiceName = Literal[
     "rds-data",
     "redshift",
     "redshift-data",
+    "redshift-serverless",
     "rekognition",
     "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
+    "rolesanywhere",
     "route53",
     "route53-recovery-cluster",
     "route53-recovery-control-config",
@@ -717,6 +731,7 @@ ServiceName = Literal[
     "storagegateway",
     "sts",
     "support",
+    "support-app",
     "swf",
     "synthetics",
     "textract",
